@@ -1,29 +1,29 @@
 # frozen_string_literal: true
-require 'net/http'
-require 'openssl'
-require 'fileutils'
+require "net/http"
+require "openssl"
+require "fileutils"
 
 URIS = [
-  URI('https://rubygems.org'),
-  URI('https://www.rubygems.org'),
-  URI('https://index.rubygems.org'),
-  URI('https://staging.rubygems.org'),
+  URI("https://rubygems.org"),
+  URI("https://www.rubygems.org"),
+  URI("https://index.rubygems.org"),
+  URI("https://staging.rubygems.org"),
 ].freeze
 
 HOSTNAMES_TO_MAP = [
-  'rubygems.org',
+  "rubygems.org",
 ].freeze
 
 def connect_to(uri, store)
   # None of the URIs are IPv6, so URI::Generic#hostname(ruby 1.9.3+) isn't needed
   http = Net::HTTP.new uri.host, uri.port
 
-  http.use_ssl = uri.scheme.downcase == 'https'
+  http.use_ssl = uri.scheme.downcase == "https"
   http.ssl_version = :TLSv1_2
   http.verify_mode = OpenSSL::SSL::VERIFY_PEER
   http.cert_store = store
 
-  http.get '/'
+  http.get "/"
 
   true
 rescue OpenSSL::SSL::SSLError
@@ -66,7 +66,7 @@ def test_certificates(certificates, uri)
         puts match.map {|certificate| certificate.subject }
         return
       else
-        print '.'
+        print "."
       end
     end
     puts
@@ -99,15 +99,15 @@ def write_certificates(certificates)
   mapping = hostname_certificate_mapping(certificates)
   mapping.each do |hostname, certificate|
     subject = certificate.subject.to_a
-    name = (subject.assoc('CN') || subject.assoc('OU'))[1]
-    name = name.delete ' .-'
+    name = (subject.assoc("CN") || subject.assoc("OU"))[1]
+    name = name.delete " .-"
 
     FileUtils.mkdir_p("lib/rubygems/ssl_certs/#{hostname}")
     destination = "lib/rubygems/ssl_certs/#{hostname}/#{name}.pem"
 
     warn "overwriting certificate #{name}" if File.exist? destination
 
-    File.open destination, 'w' do |io|
+    File.open destination, "w" do |io|
       io.write certificate.to_pem
     end
   end
